@@ -25,7 +25,7 @@
 class CollectionPathResolverTest : public QObject
 {
   Q_OBJECT
-  private slots:
+  private Q_SLOTS:
     void initTestCase();
     void testPathResolver();
     void testRoot();
